package com.ibm.ccl.ua.generators.sitexml;

/*******************************************************************************
 * Copyright (c) 2000, 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.StringReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.Date;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.jar.JarFile;
import java.util.zip.ZipEntry;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.transform.TransformerException;

import org.eclipse.update.configuration.IConfiguredSite;
import org.eclipse.update.configuration.ILocalSite;
import org.eclipse.update.core.IFeature;
import org.eclipse.update.core.IFeatureContentProvider;
import org.eclipse.update.core.INonPluginEntry;
import org.eclipse.update.core.ISite;
import org.eclipse.update.core.ISiteFeatureReference;
import org.eclipse.update.core.SiteManager;
/**
 * Servlet to handle live help action requests
 */
public class SiteXMLGenerator extends HttpServlet {
	private static final long serialVersionUID = 1L;
	CategoryMappingHandler mappingHandler = new CategoryMappingHandler();
	Hashtable categoryMappings = mappingHandler.getCategoryMappingsHash();

	
	/**
	 */
	public void init() throws ServletException {
		
	}

	/**
	 * Called by the server (via the <code>service</code> method) to allow a
	 * servlet to handle a GET request.
	 */
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		
		
		req.setCharacterEncoding("UTF-8"); //$NON-NLS-1$
		resp.setContentType("application/xml; charset=UTF-8"); //$NON-NLS-1$
		resp.setHeader("Cache-Control", "no-store, no-cache, must-revalidate");
		
//Create an Array List of IFeatures in the local site
		
		ArrayList featuresAdded = new ArrayList();
		ArrayList featuresToUpdate=new ArrayList();
		String currFeatureID;
		IFeature currFeature;
		int dupIndex=0;
		
		
		try
		{
			ILocalSite site = SiteManager.getLocalSite();
			IConfiguredSite[]sites = site.getCurrentConfiguration().getConfiguredSites();
			
			int j=0;
			
			for(j=0;j<sites.length;j++)
			{
				
				ISite uaSite = sites[j].getSite();
				ISiteFeatureReference [] uaFeatureReferences = uaSite.getFeatureReferences();
				
				int i;
				ISiteFeatureReference featureRef;
				IFeature siteFeature;
				
				for(i=0;i<uaFeatureReferences.length;i++)
				{
					featureRef = uaFeatureReferences[i];
					siteFeature=featureRef.getFeature();
					currFeatureID= siteFeature.getVersionedIdentifier().getIdentifier();
					
					
					if(featuresAdded.contains(currFeatureID)) 
					{
						//Feature already set to be added to the site.xml.  Need to check versions
						
						dupIndex=featuresAdded.indexOf(siteFeature.getVersionedIdentifier().getIdentifier());
						currFeature=(IFeature)featuresToUpdate.get(dupIndex);
						featuresToUpdate=VersionUtility.handleDuplicateFeature(featuresToUpdate, currFeature,siteFeature,dupIndex);
					
						
					}
					else
					{
						//New feature to add
						featuresToUpdate.add(siteFeature);
						featuresAdded.add(currFeatureID);
					}
					
				}
				
			}
			 
			//Generate Site XML
			String response = serialize(featuresToUpdate);
			resp.getWriter().write(response);
			
		}
		catch(Exception e)
		{
			
		}
				
	}
	/**
	 * 
	 * Called by the server (via the <code>service</code> method) to allow a
	 * servlet to handle a POST request.
	 * 
	 * Handle the search requests,
	 *  
	 */
	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		doGet(req, resp);
	}
	
	private String serialize(ArrayList featuresToUpdate) throws TransformerException {
		
		boolean updateFeature=false;
		String featureCategory;
		ArrayList featureCategories = new ArrayList();
		StringBuffer buf = new StringBuffer();
		buf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"); //$NON-NLS-1$
		buf.append("<!--"+ new Date().toString() +"-->");
		buf.append("<site>\n"); //$NON-NLS-1$
				
		String featureURL;
		//Build feature list
		for (int i = 0; i < featuresToUpdate.size(); ++i) {
			IFeature feature = (IFeature)featuresToUpdate.get(i);
			INonPluginEntry[] dataEntry =feature.getNonPluginEntries();	
			
			updateFeature=includeFeatureInUpdate(dataEntry, feature);
									
			featureCategory=getFeatureCategory(dataEntry,feature);
			
			if(!(featureCategories.contains(featureCategory)) && featureCategory!="")
			{
				featureCategories.add(featureCategory);			}
			
			if(updateFeature)
			{
				featureURL=filterFeatureURL(feature.getURL().toString());
				
				buf.append("<feature"); //$NON-NLS-1$
			
				buf.append("\n      url=\"" + featureURL + '"'); //$NON-NLS-1$
				buf.append("\n      id=\"" +  feature.getVersionedIdentifier().getIdentifier() + "\""); //$NON-NLS-1$
				
				if(featureCategory.equals(""))
				{
					buf.append("\n      version=\"" + feature.getVersionedIdentifier().getVersion()+ "\"/>\n"); //$NON-NLS-1$ //$NON-NLS-2$
				}
				else
				{
					buf.append("\n      version=\"" + feature.getVersionedIdentifier().getVersion()+ "\">\n"); //$NON-NLS-1$ //$NON-NLS-2$
				
					buf.append("\n     <category name=\"" + featureCategory+ "\"/>\n"); //$NON-NLS-1$ //$NON-NLS-2$
					
					buf.append("\n     </feature>\n"); //$NON-NLS-1$ //$NON-NLS-2$
				}
			}
		}
		
		//Add Category Defs
		int j=0;
		String currCategory;
		for(j=0;j<featureCategories.size();j++)
		{
			currCategory=(String)featureCategories.get(j);
			
			buf.append("\n     <category-def name=\"" + currCategory+ "\" label=\""+currCategory+"\"/>\n"); //$NON-NLS-1$ //$NON-NLS-2$
		}
		buf.append("</site>\n"); //$NON-NLS-1$
		return buf.toString();
	}
		
	public boolean includeFeatureInUpdate(INonPluginEntry[] dataArray, IFeature currFeature)
	{
		boolean includeInUpdate=false;
		int i=0,j, charCount;
		INonPluginEntry currEntry;
		URL featureURL, propertiesURL;
		InputStream propertiesStream;
		InputStreamReader propertiesReader;
		char[] fileChars;
		String fileString;
		
		try
		{
			IFeatureContentProvider featureProvider = currFeature.getFeatureContentProvider();
		
			for(i=0;i<dataArray.length;i++)
			{
				currEntry=dataArray[i];
				
				
				if(currEntry.getIdentifier().contains("uadelivery.properties"))  //Found uapropertiues element
				{
					//Store the Contents of the UA Delivery properties file
					featureURL=featureProvider.getURL();
					
					if(!(featureURL.toString().endsWith(".jar")))
					{
						propertiesURL=new URL(featureURL.toString()+"/"+currEntry.getIdentifier());
						propertiesStream=propertiesURL.openStream();
					}
					else
					{
						//uadelivery.properties file in JAR
						
						String filePath = featureURL.toString();
						filePath = featureURL.getFile();
						JarFile featureJAR = new JarFile(filePath);
						
						ZipEntry uaDeliveryEntry = featureJAR.getEntry("uadelivery.properties");
						propertiesStream=featureJAR.getInputStream(uaDeliveryEntry);

						
					}
					
					charCount=propertiesStream.available();
					fileChars=new char[charCount];
					propertiesReader = new InputStreamReader(propertiesStream);
					propertiesReader.read(fileChars);						
					fileString = new String(fileChars);
									
					
					//Get the value of the includeInUpdate element
					
					StringReader myReader=new StringReader(fileString);
					int includeLocation;
					String includeEntry;
					includeLocation=fileString.indexOf("includeInUpdate");
					includeLocation=includeLocation+16;		
					includeEntry=fileString.substring(includeLocation,includeLocation+4);
					
					includeEntry=includeEntry.toLowerCase();
					//If includeInUpdate = true, then set include to true
					if(includeEntry.equals("true"))
					{
						includeInUpdate=true;
					}		

					
				}
			
			}
		
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
		
		return includeInUpdate;
	}
	
	public String getFeatureCategory(INonPluginEntry[] dataArray, IFeature currFeature)
	{
		String featureCategory="";
		int i=0,j, charCount;
		INonPluginEntry currEntry;
		URL featureURL, propertiesURL=null;
		InputStream propertiesStream=null;
		InputStreamReader propertiesReader;
		char[] fileChars;
		String fileString;
		
		try
		{
			IFeatureContentProvider featureProvider = currFeature.getFeatureContentProvider();
		
			for(i=0;i<dataArray.length;i++)
			{
				currEntry=dataArray[i];
				
				if(currEntry.getIdentifier().contains("uadelivery.properties"))  //Found uapropertiues element
				{
					//Store the Contents of the UA Delivery properties file
					featureURL=featureProvider.getURL();
					
					if(!(featureURL.toString().endsWith(".jar")))
					{
						propertiesURL=new URL(featureURL.toString()+"/"+currEntry.getIdentifier());
						propertiesStream=propertiesURL.openStream();
					}
					else
					{
						//uadelivery.properties file in JAR
						
						String filePath = featureURL.toString();
						filePath = featureURL.getFile();
						JarFile featureJAR = new JarFile(filePath);
						
						ZipEntry uaDeliveryEntry = featureJAR.getEntry("uadelivery.properties");
						propertiesStream=featureJAR.getInputStream(uaDeliveryEntry);

						
					}
					
					charCount=propertiesStream.available();
					fileChars=new char[charCount];
					propertiesReader = new InputStreamReader(propertiesStream);
					propertiesReader.read(fileChars);						
					fileString = new String(fileChars);
									
					
					//Get the value of the includeInUpdate element
					
					StringReader myReader=new StringReader(fileString);
					int categoryLocation;
					String categoryEntry;
					categoryLocation=fileString.indexOf("category");
					
					if(categoryLocation!=-1)
					{
						categoryLocation=categoryLocation+9;		
						categoryEntry=fileString.substring(categoryLocation,fileString.length());
					
						StringTokenizer categoryTokenizer = new StringTokenizer(categoryEntry,"\n");
						categoryEntry=categoryTokenizer.nextToken();
						featureCategory=categoryEntry;
						
						//Check if category is mapped to another category
						String currMapCategory = (String)categoryMappings.get(featureCategory);
						
						if(currMapCategory!=null)
						{
							//Category has map entry in the hash table and needs to be mapped
							featureCategory=currMapCategory;
						}
						
					}
					else
					{
						featureCategory="";
					}
				}
			
			}
		
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
		
		return filterFeatureCategory(featureCategory);
	}
	
	
	public String filterFeatureURL(String featureURL)
	{
		String filteredURL;
			
		int featureIndex=featureURL.lastIndexOf("features/");
		filteredURL=featureURL.substring(featureIndex);
		
		return filteredURL;
	}
	
	public String filterJARPath(String jarPath)
	{
		String newJARPath;
		
		newJARPath=jarPath.replace("/","\\");
		
		newJARPath=jarPath.substring(6);
		
		return newJARPath;
	}
	
	public String filterFeatureCategory(String currCategory)
	{
		String filteredCategory;
		filteredCategory=currCategory.replace("/r", "");
		return filteredCategory.trim();
	}
	
}
